#!/usr/bin/env node
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var awsSdk = require('aws-sdk');
var readline = require('readline');

var __awaiter = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const kms = new awsSdk.KMS();
const isBase64 = /^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$/;
const dictionary = new Map();
function decrypt(ciphertext) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield kms
            .decrypt({ CiphertextBlob: Buffer.from(ciphertext, 'base64') })
            .promise();
        const plaintext = result.Plaintext ? result.Plaintext.toString() : ciphertext;
        return dictionary.set(ciphertext, plaintext) && plaintext;
    });
}
var kmsDecrypt = (ciphertext) => ciphertext.length === 0 ||
    process.env.DISABLE_AWS_KMS_THINGY ||
    !isBase64.test(ciphertext)
    ? String(ciphertext)
    :
        dictionary.get(ciphertext) ||
            decrypt(ciphertext);

var __awaiter$1 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const kms$1 = new awsSdk.KMS();
const dictionary$1 = new Map();
function encrypt({ plaintext, keyId, }) {
    return __awaiter$1(this, void 0, void 0, function* () {
        const result = yield kms$1
            .encrypt({ KeyId: keyId, Plaintext: plaintext })
            .promise();
        const ciphertext = result.CiphertextBlob
            ? result.CiphertextBlob.toString('base64')
            : plaintext;
        return dictionary$1.set(plaintext, ciphertext) && ciphertext;
    });
}
var kmsEncrypt = ({ plaintext, keyId, }) => process.env.DISABLE_AWS_KMS_THINGY
    ? String(plaintext)
    :
        dictionary$1.get(keyId + plaintext) ||
            encrypt({ plaintext, keyId });

var __awaiter$2 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const encrypt$1 = (parameters) => __awaiter$2(undefined, void 0, void 0, function* () {
    return 'plaintext' in parameters
        ? kmsEncrypt(parameters)
        : Promise.all(parameters.map(kmsEncrypt));
});
const decrypt$1 = (ciphertext) => __awaiter$2(undefined, void 0, void 0, function* () {
    return typeof ciphertext === 'undefined'
        ? undefined
        : typeof ciphertext === 'string'
            ? kmsDecrypt(ciphertext)
            : Promise.all(ciphertext.map(kmsDecrypt));
});

var __awaiter$3 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const COLUMNS = process.stdout.columns || 32;
const askQuestion = (question, prompt = '→', sensitive = false) => {
    const line = readline.createInterface({
        input: process.stdin,
        output: process.stdout,
    });
    return new Promise(resolve => line.question(`\n${question}:\n\n${prompt} `, answer => !line.close() &&
        (sensitive
            ? !readline.moveCursor(process.stdin, 0, -1) &&
                !readline.clearLine(process.stdin, 0) &&
                !console.log(prompt + '  ' + '*'.repeat(answer.length))
            : true) &&
        resolve(answer.trim())));
};
const printUsageText = () => console.info(`
Usage: aws-kms-thingy [command]

Commands:
  - encrypt       Encrypt a string with an AWS KMS key
  - decrypt       Decrypt ciphertext encrypted with AWS KMS
`);
const prettyResult = (title, text) => !console.log(`\n${'〰️'.repeat((COLUMNS - (title.length + 2)) / 4)} ${title} ${'〰️'.repeat((COLUMNS - (title.length + 2)) / 4)}\n`, text, `\n${'〰️'.repeat(COLUMNS / 2)}\n`) && text;
function encrypt$2() {
    return __awaiter$3(this, void 0, void 0, function* () {
        const keyId = process.env.AWS_KMS_KEY_ARN ||
            (yield askQuestion('Please enter AWS KMS Key ARN to use'));
        const plaintext = yield askQuestion('Enter plain text to encrypt', '🔓', true);
        const result = (yield encrypt$1({ keyId, plaintext }));
        return prettyResult('🔐 Encrypted', result);
    });
}
function decrypt$2() {
    return __awaiter$3(this, void 0, void 0, function* () {
        const ciphertext = yield askQuestion('Enter ciphertext to decrypt', '🔐');
        const result = (yield decrypt$1(ciphertext));
        return prettyResult('🔓 Decrypted', result);
    });
}
function main([, , action] = process.argv) {
    return __awaiter$3(this, void 0, void 0, function* () {
        const actions = {
            decrypt: decrypt$2,
            encrypt: encrypt$2,
        };
        return action && action in actions
            ? !console.log(`aws-kms-thingy ${action}`) && actions[action]()
            : printUsageText();
    });
}
main().catch(console.error);

exports.main = main;
