var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { main } from './cli';
const argvBase = [
    '/usr/local/bin/node',
    '/home/mockUser',
];
const mockDecryptedValue = 'foobar';
const mockEncryptedValue = Buffer.from(mockDecryptedValue).toString('base64');
jest.mock('readline', () => ({
    clearLine: jest.fn(),
    createInterface: () => ({
        close: jest.fn(),
        question: (questionText, callback) => callback(questionText.match('encrypted')
            ? mockEncryptedValue
            : mockDecryptedValue),
    }),
    moveCursor: jest.fn(),
}));
describe('cli', () => {
    it('should be able to encrypt a string', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield main([...argvBase, 'encrypt']);
        expect(result).toBe(mockEncryptedValue);
    }));
    it('should be able to decrypt an encrypted string', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield main([...argvBase, 'decrypt']);
        expect(result).toBe(mockDecryptedValue);
    }));
    it('should print usage info if no command specified', () => __awaiter(this, void 0, void 0, function* () {
        process.stdout.columns = undefined;
        jest.resetAllMocks();
        jest.resetModules();
        jest.resetModuleRegistry();
        const consoleSpy = jest.spyOn(console, 'info');
        const cli = require('./cli');
        const result = yield cli.main();
        expect(result).toBe(undefined);
        expect(consoleSpy).toHaveBeenCalled();
        expect(consoleSpy.mock.calls[0][0]).toContain('Usage:');
    }));
});
