var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import kmsDecrypt, { dictionary } from './decrypt';
const mockDecryptedValue = 'foobar';
const mockEncryptedValue = Buffer.from(mockDecryptedValue).toString('base64');
describe('decrypt()', () => {
    it('should decrypt an encrypted string and store it in cache', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield kmsDecrypt(mockEncryptedValue);
        expect(result).toBe(mockDecryptedValue);
        expect(dictionary.get(mockEncryptedValue)).toBe(mockDecryptedValue);
    }));
    it('should use cache if item exists in cache', () => __awaiter(this, void 0, void 0, function* () {
        const encryptedValue = Buffer.from('foobar').toString('base64');
        dictionary.clear();
        dictionary.set(encryptedValue, 'cached');
        const result = yield kmsDecrypt(encryptedValue);
        expect(result).toBe('cached');
    }));
    it('should return value as-is if not a base64 encoded secret', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield kmsDecrypt(mockDecryptedValue);
        expect(result).toBe(mockDecryptedValue);
    }));
    it('should return original value if error occurred decrypting with SDK', () => __awaiter(this, void 0, void 0, function* () {
        const mockError = Buffer.from('mockError').toString('base64');
        const result = yield kmsDecrypt(mockError);
        expect(result).toBe(mockError);
    }));
    it('should return value as is if DISABLE_AWS_KMS_THINGY is set', () => __awaiter(this, void 0, void 0, function* () {
        process.env.DISABLE_AWS_KMS_THINGY = 'true';
        const result = yield kmsDecrypt(mockEncryptedValue);
        expect(result).toBe(mockEncryptedValue);
        delete process.env.DISABLE_AWS_KMS_THINGY;
    }));
});
