var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import kmsEncrypt, { dictionary } from './encrypt';
const mockDecryptedValue = 'foobar';
const mockEncryptedValue = Buffer.from(mockDecryptedValue).toString('base64');
const keyId = 'foobar-key';
const mock = (plaintext) => ({ keyId, plaintext });
describe('encrypt()', () => {
    it('should encrypt a string and store it in cache', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield kmsEncrypt(mock(mockDecryptedValue));
        expect(result).toBe(mockEncryptedValue);
        expect(dictionary.get(mockDecryptedValue)).toBe(mockEncryptedValue);
    }));
    it('should use cache if item exists in cache', () => __awaiter(this, void 0, void 0, function* () {
        dictionary.clear();
        dictionary.set(keyId + mockDecryptedValue, 'cached');
        const result = yield kmsEncrypt(mock(mockDecryptedValue));
        expect(result).toBe('cached');
    }));
    it('should return original value if error occurred encrypting with SDK', () => __awaiter(this, void 0, void 0, function* () {
        const mockError = 'mockError';
        const result = yield kmsEncrypt(mock(mockError));
        expect(result).toBe(mockError);
    }));
    it('should return value as is if DISABLE_AWS_KMS_THINGY is set', () => __awaiter(this, void 0, void 0, function* () {
        process.env.DISABLE_AWS_KMS_THINGY = 'true';
        const result = yield kmsEncrypt(mock(mockDecryptedValue));
        expect(result).toBe(mockDecryptedValue);
        delete process.env.DISABLE_AWS_KMS_THINGY;
    }));
});
